@@ -319,6 +319,7 @@ __all__ = (
     "MoveStatusType",
     "MulticastSupportValueType",
     "NatGatewayAvailableWaiterName",
+    "NatGatewayDeletedWaiterName",
     "NatGatewayStateType",
     "NetworkInterfaceAttributeType",
     "NetworkInterfaceAvailableWaiterName",
@@ -936,6 +937,17 @@ InstanceTypeType = Literal[
     "c5n.large",
     "c5n.metal",
     "c5n.xlarge",
+    "c6a.12xlarge",
+    "c6a.16xlarge",
+    "c6a.24xlarge",
+    "c6a.2xlarge",
+    "c6a.32xlarge",
+    "c6a.48xlarge",
+    "c6a.4xlarge",
+    "c6a.8xlarge",
+    "c6a.large",
+    "c6a.metal",
+    "c6a.xlarge",
     "c6g.12xlarge",
     "c6g.16xlarge",
     "c6g.2xlarge",
@@ -1153,6 +1165,7 @@ InstanceTypeType = Literal[
     "m6a.4xlarge",
     "m6a.8xlarge",
     "m6a.large",
+    "m6a.metal",
     "m6a.xlarge",
     "m6g.12xlarge",
     "m6g.16xlarge",
@@ -1349,6 +1362,16 @@ InstanceTypeType = Literal[
     "x2gd.medium",
     "x2gd.metal",
     "x2gd.xlarge",
+    "x2idn.16xlarge",
+    "x2idn.24xlarge",
+    "x2idn.32xlarge",
+    "x2iedn.16xlarge",
+    "x2iedn.24xlarge",
+    "x2iedn.2xlarge",
+    "x2iedn.32xlarge",
+    "x2iedn.4xlarge",
+    "x2iedn.8xlarge",
+    "x2iedn.xlarge",
     "x2iezn.12xlarge",
     "x2iezn.2xlarge",
     "x2iezn.4xlarge",
@@ -1454,6 +1477,7 @@ MonitoringStateType = Literal["disabled", "disabling", "enabled", "pending"]
 MoveStatusType = Literal["movingToVpc", "restoringToClassic"]
 MulticastSupportValueType = Literal["disable", "enable"]
 NatGatewayAvailableWaiterName = Literal["nat_gateway_available"]
+NatGatewayDeletedWaiterName = Literal["nat_gateway_deleted"]
 NatGatewayStateType = Literal["available", "deleted", "deleting", "failed", "pending"]
 NetworkInterfaceAttributeType = Literal["attachment", "description", "groupSet", "sourceDestCheck"]
 NetworkInterfaceAvailableWaiterName = Literal["network_interface_available"]
@@ -2235,6 +2259,7 @@ WaiterName = Literal[
     "internet_gateway_exists",
     "key_pair_exists",
     "nat_gateway_available",
+    "nat_gateway_deleted",
     "network_interface_available",
     "password_data_available",
     "security_group_exists",
