@@ -27,6 +27,7 @@ Usage::
         InternetGatewayExistsWaiter,
         KeyPairExistsWaiter,
         NatGatewayAvailableWaiter,
+        NatGatewayDeletedWaiter,
         NetworkInterfaceAvailableWaiter,
         PasswordDataAvailableWaiter,
         SecurityGroupExistsWaiter,
@@ -65,6 +66,7 @@ Usage::
     internet_gateway_exists_waiter: InternetGatewayExistsWaiter = client.get_waiter("internet_gateway_exists")
     key_pair_exists_waiter: KeyPairExistsWaiter = client.get_waiter("key_pair_exists")
     nat_gateway_available_waiter: NatGatewayAvailableWaiter = client.get_waiter("nat_gateway_available")
+    nat_gateway_deleted_waiter: NatGatewayDeletedWaiter = client.get_waiter("nat_gateway_deleted")
     network_interface_available_waiter: NetworkInterfaceAvailableWaiter = client.get_waiter("network_interface_available")
     password_data_available_waiter: PasswordDataAvailableWaiter = client.get_waiter("password_data_available")
     security_group_exists_waiter: SecurityGroupExistsWaiter = client.get_waiter("security_group_exists")
@@ -107,6 +109,7 @@ __all__ = (
     "InternetGatewayExistsWaiter",
     "KeyPairExistsWaiter",
     "NatGatewayAvailableWaiter",
+    "NatGatewayDeletedWaiter",
     "NetworkInterfaceAvailableWaiter",
     "PasswordDataAvailableWaiter",
     "SecurityGroupExistsWaiter",
@@ -483,6 +486,28 @@ class NatGatewayAvailableWaiter(Boto3Waiter):
         """
 
 
+class NatGatewayDeletedWaiter(Boto3Waiter):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.NatGatewayDeleted)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#natgatewaydeletedwaiter)
+    """
+
+    def wait(
+        self,
+        *,
+        DryRun: bool = ...,
+        Filters: Sequence["FilterTypeDef"] = ...,
+        MaxResults: int = ...,
+        NatGatewayIds: Sequence[str] = ...,
+        NextToken: str = ...,
+        WaiterConfig: "WaiterConfigTypeDef" = ...
+    ) -> None:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.NatGatewayDeleted.wait)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#natgatewaydeletedwaiter)
+        """
+
+
 class NetworkInterfaceAvailableWaiter(Boto3Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.NetworkInterfaceAvailable)
